// title:  game title
// author: Fabien Freling
// desc:   (Major Jam 8)
// script: wren

import "random" for Random

var W = 240
var H = 136
var R = Random.new()

class Star {
	construct new(x, y, size, scrollSpeed, color) {
		_x = x
		_y = y
		_size = size
		_scrollSpeed = scrollSpeed
		_color = color
	}

	update() {
		_x = _x - _scrollSpeed
	}

	draw() {
		TIC.circ(_x, _y, _size, _color)
	}
}

class World {
	construct new() {
		_t = 0
		_stars = []
		for (i in 0..W) {
			update()
		}
	}

	update() {
		for (s in _stars) {
			s.update()
		}
		// small stars
		if (_t % 30 == 0) {
			_stars.add(Star.new(W, R.int(0,H), 1, 1, 12))
		}
		// medium stars
		var width = 10
		var spaceBetween = width * 5
		var speed = 0.1
		var mediumTick = (spaceBetween + width) / speed
		if (_t % mediumTick == 0) {
			_stars.add(Star.new(W, R.int(0,H), width, speed, 13))
		}
		_t = _t + 1
	}

	draw() {
		for (s in _stars) {
			s.draw()
		}
	}
}

class Game is TIC{
	state { _state }
	static start { "start" }
	static game { "game" }

	construct new() {
		_t=0
		_x=96
		_y=24
		_state = Game.start
		_world = World.new()
	}
	
	TIC() {
		update()
		draw()
		_t=_t+1
	}

	update() {
		if(TIC.btn(0)){
			_y=_y-1
		}
		if(TIC.btn(1)){
			_y=_y+1
		}
		if(TIC.btn(2)){
			_x=_x-1
		}
		if(TIC.btn(3)){
			_x=_x+1
		}
		_world.update()
	}

	draw() {
		TIC.cls(0)
		_world.draw()
		//TIC.spr(1+((_t%60)/30|0)*2,_x,_y,14,3,0,0,2,2)
		//TIC.print("HELLO WORLD!",84,84)
	}
}

// <TILES>
// 001:eccccccccc888888caaaaaaaca888888cacccccccacc0ccccacc0ccccacc0ccc
// 002:ccccceee8888cceeaaaa0cee888a0ceeccca0ccc0cca0c0c0cca0c0c0cca0c0c
// 003:eccccccccc888888caaaaaaaca888888cacccccccacccccccacc0ccccacc0ccc
// 004:ccccceee8888cceeaaaa0cee888a0ceeccca0cccccca0c0c0cca0c0c0cca0c0c
// 017:cacccccccaaaaaaacaaacaaacaaaaccccaaaaaaac8888888cc000cccecccccec
// 018:ccca00ccaaaa0ccecaaa0ceeaaaa0ceeaaaa0cee8888ccee000cceeecccceeee
// 019:cacccccccaaaaaaacaaacaaacaaaaccccaaaaaaac8888888cc000cccecccccec
// 020:ccca00ccaaaa0ccecaaa0ceeaaaa0ceeaaaa0cee8888ccee000cceeecccceeee
// </TILES>

// <WAVES>
// 000:00000000ffffffff00000000ffffffff
// 001:0123456789abcdeffedcba9876543210
// 002:0123456789abcdef0123456789abcdef
// </WAVES>

// <SFX>
// 000:000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000304000000000
// </SFX>

// <PALETTE>
// 000:1a1c2c5d275db13e53ef7d57ffcd75a7f07038b76425717929366f3b5dc941a6f673eff7f4f4f494b0c2566c86333c57
// </PALETTE>

